@@ -5,6 +5,7 @@ from users_and_computers.models import RiskAssignment
 
 class RiskVMPanel(PluginTemplateExtension):
     model = 'plugins.users_and_computers.aduser'
+    model = 'users_and_computers.aduser'
     # model = 'virtualization.virtualmachine'
 
     def right_page(self):
@@ -27,6 +28,7 @@ class RiskVMPanel(PluginTemplateExtension):
 class RiskDevicePanel(PluginTemplateExtension):
     # model = 'dcim.device'
     model = 'plugins.users_and_computers.ad_users'
+    model = 'users_and_computers.ad_users'
 
     def right_page(self):
         risk = self.context['object']
